%--------------------------------------------------------------------------
% File     : RNG007-5 : TPTP v3.2.0. Released v1.0.0.
% Domain   : Ring Theory
% Problem  : In Boolean rings, X is its own inverse
% Version  : [MOW76] axioms : Augmented.
%            Theorem formulation : Equality.
% English  : Given a ring in which for all x, x * x = x, prove that for 
%            all x, x + x = additive_identity.

% Refs     : [MOW76] McCharen et al. (1976), Problems and Experiments for a
%          : [PS81]  Peterson & Stickel (1981), Complete Sets of Reductions
% Source   : [ANL]
% Names    : lemma.ver1.in [ANL]

% Status   : Satisfiable
% Rating   : 0.33 v3.2.0, 0.80 v3.1.0, 0.67 v2.7.0, 0.33 v2.6.0, 0.86 v2.5.0, 0.50 v2.4.0, 0.67 v2.2.1, 0.75 v2.2.0, 0.67 v2.1.0, 1.00 v2.0.0
% Syntax   : Number of clauses     :   25 (   0 non-Horn;  14 unit;  13 RR)
%            Number of atoms       :   58 (   3 equality)
%            Maximal clause size   :    5 (   2 average)
%            Number of predicates  :    3 (   0 propositional; 2-3 arity)
%            Number of functors    :    5 (   2 constant; 0-2 arity)
%            Number of variables   :   79 (   2 singleton)
%            Maximal term depth    :    3 (   1 average)

% Comments : Extra lemmas based on [PS81] equality axioms.
%--------------------------------------------------------------------------
%----Include ring theory axioms 
include('Axioms/RNG001-0.ax').
%--------------------------------------------------------------------------
%----The next six clauses are the extra lemmas.
%----Inverse of identity is identity 
cnf(additive_inverse_identity,axiom,
    ( sum(additive_inverse(additive_identity),additive_identity,additive_identity) )).

%----Inverse of inverse of X is X 
cnf(additive_inverse_additive_inverse,axiom,
    ( sum(additive_inverse(additive_inverse(X)),additive_identity,X) )).

%----Behavior of additive_identity and the multiplication operation 
cnf(multiply_additive_id1,axiom,
    ( product(X,additive_identity,additive_identity) )).

cnf(multiply_additive_id2,axiom,
    ( product(additive_identity,X,additive_identity) )).

%----Inverse of (x + y) is additive_inverse(x) + additive_inverse(y), 
cnf(distribute_additive_inverse,axiom,
    ( sum(additive_inverse(X),additive_inverse(Y),additive_inverse(add(X,Y))) )).

%----x * additive_inverse(y) = additive_inverse (x * y), 
cnf(multiply_additive_inverse,axiom,
    ( product(X,additive_inverse(Y),additive_inverse(multiply(X,Y))) )).

%----Clauses for the theorem 
cnf(x_squared_is_x,hypothesis,
    ( product(X,X,X) )).

cnf(prove_a_plus_a_is_id,negated_conjecture,
    (  multiply(a,a) != additive_identity )).

%--------------------------------------------------------------------------
